@@ -289,7 +289,12 @@ int bt_string_to_uuid(bt_uuid_t *uuid, const char *string)
 
 int bt_uuid_strcmp(const void *a, const void *b)
 {
-	return strcasecmp(a, b);
+	bt_uuid_t u1, u2;
+
+	bt_string_to_uuid(&u1, a);
+	bt_string_to_uuid(&u2, b);
+
+	return bt_uuid_cmp(&u1, &u2);
 }
 
 int bt_uuid_to_le(const bt_uuid_t *src, void *dst)
@@ -301,7 +306,8 @@ int bt_uuid_to_le(const bt_uuid_t *src, void *dst)
 		bt_put_le16(src->value.u16, dst);
 		return 0;
 	case BT_UUID32:
-		bt_uuid_to_uuid128(src, &uuid);
+		bt_uuid32_to_uuid128(src, &uuid);
+		src = &uuid;
 		/* Fallthrough */
 	case BT_UUID128:
 		/* Convert from 128-bit BE to LE */
