@@ -185,16 +185,20 @@ int service_accept(struct btd_service *service)
 	int err;
 
 	if (!service->profile->accept)
-		return 0;
+		goto done;
 
 	err = service->profile->accept(service);
 	if (!err)
-		return 0;
+		goto done;
 
 	ba2str(device_get_address(service->device), addr);
 	error("%s profile accept failed for %s", service->profile->name, addr);
 
 	return err;
+
+done:
+	change_state(service, BTD_SERVICE_STATE_CONNECTING, 0);
+	return 0;
 }
 
 int btd_service_connect(struct btd_service *service)
@@ -336,8 +340,7 @@ bool btd_service_remove_state_cb(unsigned int id)
 
 void btd_service_connecting_complete(struct btd_service *service, int err)
 {
-	if (service->state != BTD_SERVICE_STATE_DISCONNECTED &&
-				service->state != BTD_SERVICE_STATE_CONNECTING)
+	if (service->state != BTD_SERVICE_STATE_CONNECTING)
 		return;
 
 	if (err == 0)
